.. Emperor documentation master file, created by
   sphinx-quickstart on Sat Sep 13 10:33:08 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Emperor's Documentation
=======================

Emperor is an interactive next generation tool for the analysis, visualization
and understanding of high throughput microbial ecology datasets.

This section of the documentation describes the usage of Emperor's main command
line interface `make_emperor.py`.

The :ref:`genindex` lists the contents of this documentation.

Citing Emperor
==============

Remember to cite Emperor If you use it in any published research, please
include the following citation:

.. note::
	**EMPeror: a tool for visualizing high-throughput microbial community data**. Vazquez-Baeza Y, Pirrung M, Gonzalez A, Knight R. Gigascience. 2013 Nov 26;2(1):16.


You can find the `Emperor paper here <http://www.gigasciencejournal.com/content/2/1/16/>`_, and the data presented in this paper can be found `here <http://gigadb.org/dataset/100068>`_.

Animations:
===========

.. toctree::
   :maxdepth: 1

   tutorials/animations

Scripts:
========

.. toctree::
   :maxdepth: 2

   scripts/make_emperor
   tutorials/animations

Classes:
========

.. toctree::
   :maxdepth: 4

   emperor_objects

Format Description:
===================

.. toctree::
   :maxdepth: 2

   formats

